@@ -1,6 +1,6 @@
 #![no_std]
 
-use serde::{Serialize, Deserialize};
+use serde::{Deserialize, Serialize};
 
 use ross_protocol::packet::Packet;
 
@@ -17,6 +17,7 @@ pub enum StateValue {
     U8(u8),
     U16(u16),
     U32(u32),
+    Bool(bool),
 }
 
 #[derive(Debug, PartialEq)]
