@@ -2,7 +2,7 @@ use ross_protocol::packet::Packet;
 
 use crate::producer::Producer;
 use crate::state::StateManager;
-use crate::Value;
+use crate::ExtractorValue;
 
 #[repr(C)]
 #[derive(Debug)]
@@ -17,7 +17,7 @@ impl NoneProducer {
 impl Producer for NoneProducer {
     fn produce(
         &self,
-        _value: Value,
+        _value: ExtractorValue,
         _state_manager: &StateManager,
         _device_address: u16,
     ) -> Option<Packet> {
